@@ -680,7 +680,7 @@ test_that("check_site_generator generates warning from wflow_build", {
 test_that("is_rmd distinguishes between Rmd and non-Rmd files", {
   expect_identical(workflowr:::is_rmd("file.Rmd"), TRUE)
   expect_identical(workflowr:::is_rmd("file.rmd"), TRUE)
-  expect_identical(workflowr:::is_rmd(c("file.Rmd", "file.rmd")), c(TRUE, TRUE))
+  expect_identical(workflowr:::is_rmd(c("file.Rmd", "file.rmd")), TRUE)
 
   expect_identical(workflowr:::is_rmd("file.md"), FALSE)
   expect_identical(workflowr:::is_rmd("file.RRmd"), FALSE)
@@ -691,5 +691,23 @@ test_that("is_rmd distinguishes between Rmd and non-Rmd files", {
   expect_identical(
     workflowr:::is_rmd(c("path/to/file.md", "path/to/file.Rmd",
                          "path/to/file.Rrmd", "path/to/file.rmd")),
-    c(FALSE, TRUE, FALSE, TRUE))
+    FALSE)
+})
+
+# Test check_wd_exists() -------------------------------------------------------
+
+test_that("check_wd_exists throws error if working directory has been deleted", {
+
+  if (.Platform$OS.type == "windows")
+    skip("Current working directory cannot be deleted on Windows")
+
+  cwd <- fs::path_wd()
+  on.exit(setwd(cwd))
+
+  path <- fs::file_temp()
+  fs::dir_create(path)
+  setwd(path)
+  expect_silent(check_wd_exists())
+  fs::dir_delete(path)
+  expect_error(check_wd_exists(), "The current working directory doesn't exist.")
 })
